@@ -1,15 +1,15 @@
 import asyncio
 import warnings
+from typing import Optional, Iterable
 
-from asn1crypto import pem
-from asn1crypto.x509 import Certificate
+from asn1crypto import x509
 
 from .context import ValidationContext, PKIXValidationParams
 from .errors import ValidationError, PathBuildingError, InvalidCertificateError
 from .validate import async_validate_path, validate_tls_hostname, validate_usage
 from .version import __version__, __version_info__
 from ._errors import pretty_message
-from ._types import type_name, str_cls, byte_cls
+from ._types import type_name
 
 
 __all__ = [
@@ -21,7 +21,7 @@ __all__ = [
 ]
 
 
-class CertificateValidator():
+class CertificateValidator:
 
     # A pyhanko_certvalidator.context.ValidationContext object
     _context = None
@@ -35,18 +35,20 @@ class CertificateValidator():
     # A pyhanko_certvalidator.context.PKIXValidationParams object
     _params = None
 
-    def __init__(self, end_entity_cert, intermediate_certs=None,
-                 validation_context: ValidationContext = None,
-                 pkix_params: PKIXValidationParams = None):
+    def __init__(
+            self,
+            end_entity_cert: x509.Certificate,
+            intermediate_certs: Optional[Iterable[x509.Certificate]] = None,
+            validation_context: Optional[ValidationContext] = None,
+            pkix_params: PKIXValidationParams = None):
         """
         :param end_entity_cert:
-            An asn1crypto.x509.Certificate object or a byte string of the DER or
-            PEM-encoded X.509 end-entity certificate to validate
+            An asn1crypto.x509.Certificate object X.509 end-entity
+            certificate to validate
 
         :param intermediate_certs:
-            None or a list of asn1crypto.x509.Certificate objects or a byte
-            string of a DER or PEM-encoded X.509 certificate. Used in
-            constructing certificate paths for validation.
+            None or a list of asn1crypto.x509.Certificate
+            Used in constructing certificate paths for validation.
 
         :param validation_context:
             A pyhanko_certvalidator.context.ValidationContext() object that
@@ -65,31 +67,9 @@ class CertificateValidator():
             settings.
         """
 
-        if not isinstance(end_entity_cert, Certificate):
-            if not isinstance(end_entity_cert, byte_cls):
-                raise TypeError(pretty_message(
-                    '''
-                    end_entity_cert must be a byte string or an instance of
-                    asn1crypto.x509.Certificate, not %s
-                    ''',
-                    type_name(end_entity_cert)
-                ))
-            if pem.detect(end_entity_cert):
-                _, _, end_entity_cert = pem.unarmor(end_entity_cert)
-            end_entity_cert = Certificate.load(end_entity_cert)
-
         if validation_context is None:
             validation_context = ValidationContext()
 
-        if not isinstance(validation_context, ValidationContext):
-            raise TypeError(pretty_message(
-                '''
-                validation_context must be an instance of
-                pyhanko_certvalidator.context.ValidationContext, not %s
-                ''',
-                type_name(validation_context)
-            ))
-
         if intermediate_certs is not None:
             certificate_registry = validation_context.certificate_registry
             for intermediate_cert in intermediate_certs:
@@ -142,7 +122,7 @@ class CertificateValidator():
                 await async_validate_path(self._context, candidate_path, self._params)
                 self._path = candidate_path
                 return
-            except (ValidationError) as e:
+            except ValidationError as e:
                 exceptions.append(e)
 
         if len(exceptions) == 1:
@@ -150,7 +130,7 @@ class CertificateValidator():
 
         non_signature_exception = None
         for exception in exceptions:
-            if 'signature' not in str_cls(exception):
+            if 'signature' not in str(exception):
                 non_signature_exception = exception
 
         if non_signature_exception:
