@@ -1,8 +1,8 @@
-from typing import Iterable
+from typing import Iterable, Union
 import logging
 import requests
 
-from asn1crypto import x509
+from asn1crypto import x509, cms
 
 from ...errors import CertificateFetchError
 from ..api import CertificateFetcher
@@ -56,14 +56,19 @@ class RequestsCertificateFetcher(CertificateFetcher, RequestsFetcherMixin):
             return results
         return await self._perform_fetch(url, task)
 
-    def fetch_cert_issuers(self, cert: x509.Certificate):
+    def fetch_cert_issuers(
+            self, cert: Union[x509.Certificate, cms.AttributeCertificateV2]):
         fetch_jobs = [
             self.fetch_certs(url, url_origin_type='certificate')
             for url in gather_aia_issuer_urls(cert)
         ]
-        logger.info(
-            f"Retrieving issuer certs for {cert.subject.human_friendly}..."
-        )
+
+        if isinstance(cert, x509.Certificate):
+            target = cert.subject.human_friendly
+        else:
+            # TODO log audit ID
+            target = "attribute certificate"
+        logger.info(f"Retrieving issuer certs for {target}...")
         return complete_certificate_fetch_jobs(fetch_jobs)
 
     async def fetch_crl_issuers(self, certificate_list):
